@@ -10,7 +10,7 @@ x <- queryHaploreg(query=c("rs10048158","rs4791078"))
 x
 
 ## ---- echo=TRUE, message=FALSE-------------------------------------------
-subset.high.LD <- x[x$r2 > 0.9, c("rsID", "r2", "chr", "pos_hg38", "is_query_snp", "ref", "alt")]
+subset.high.LD <- x[as.numeric(x$r2) > 0.9, c("rsID", "r2", "chr", "pos_hg38", "is_query_snp", "ref", "alt")]
 subset.high.LD
 
 ## ---- echo=TRUE, message=FALSE, eval=FALSE-------------------------------
@@ -50,6 +50,17 @@ x <- queryRegulome(c("rs4791078","rs10048158"))
 x$res.table
 x$bad.snp.id
 
+## ---- echo=TRUE, message=FALSE-------------------------------------------
+library(haploR)
+ldmat <- LDlink.LDmatrix(snps=c("rs77264218", "rs11229158", "rs10896659", "rs10896702", "rs2042592"), population="AFR")
+ldmat
+# Stylish matrix R2
+stylish.matrix.r2 <- makeStylishLDmatrix(ldmat$matrix.r2)
+stylish.matrix.r2
+# Stylish matrix D'
+stylish.matrix.Dprime <- makeStylishLDmatrix(ldmat$matrix.dprime)
+stylish.matrix.Dprime
+
 ## ---- echo=TRUE----------------------------------------------------------
 sessionInfo()
 
